# Stubs for rdflib.parser (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from io import StringIO as BytesIO

class Parser:
    def __init__(self): ...
    def parse(self, source, sink): ...
