# Stubs for avro (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

# Names in __all__ with no definition:
#   datafile
#   io
#   ipc
#   protocol
#   schema
