# Stubs for rdflib.plugin (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from rdflib.exceptions import Error
from rdflib.parser import Parser

class PluginException(Error): ...

class Plugin:
    name = ... # type: Any
    kind = ... # type: Any
    module_path = ... # type: Any
    class_name = ... # type: Any
    def __init__(self, name, kind, module_path, class_name): ...
    def getClass(self): ...

class PKGPlugin(Plugin):
    name = ... # type: Any
    kind = ... # type: Any
    ep = ... # type: Any
    def __init__(self, name, kind, ep): ...
    def getClass(self): ...

def register(name: str, kind: type, module_path: str, class_name: str) -> None: ...
def get(name, kind): ...
def plugins(name=None, kind=None): ...
