# Stubs for ruamel.yaml.parser (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from ruamel.yaml.error import MarkedYAMLError

class ParserError(MarkedYAMLError): ...
