# Stubs for posixpath (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from genericpath import *
from typing import Any, AnyStr, List

curdir: str
pardir: str
extsep: str
sep: str
pathsep: str
defpath: str
altsep: Any
devnull: str

def normcase(s): ...
def isabs(s: AnyStr) -> bool: ...
def join(a: AnyStr, *p: AnyStr) -> AnyStr: ...
def split(p: AnyStr) -> List[AnyStr]: ...
def splitext(p): ...
def splitdrive(p): ...
def basename(p: AnyStr) -> AnyStr: ...
def dirname(p): ...
def islink(path): ...
def lexists(path): ...
def samefile(f1, f2): ...
def sameopenfile(fp1, fp2): ...
def samestat(s1, s2): ...
def ismount(path): ...
def walk(top, func, arg): ...
def expanduser(path): ...
def expandvars(path): ...
def normpath(path): ...
def abspath(path): ...
def realpath(filename): ...

supports_unicode_filenames: Any

def relpath(path, start: Any = ...): ...

# Names in __all__ with no definition:
#   commonprefix
#   exists
#   getatime
#   getctime
#   getmtime
#   getsize
#   isdir
#   isfile
