# Stubs for ruamel.yaml.main (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from ruamel.yaml.loader import *

def load(stream, Loader: Any =..., version=None) -> Any: ...
