# Stubs for rdflib (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from rdflib.term import URIRef as URIRef, BNode as BNode, Literal as Literal, Variable as Variable
from rdflib.namespace import Namespace as Namespace
from rdflib.graph import Dataset as Dataset, Graph as Graph, ConjunctiveGraph as ConjunctiveGraph
from rdflib.namespace import RDF as RDF, RDFS as RDFS, OWL as OWL, XSD as XSD
from rdflib import util as util
