# Stubs for rdflib.serializer (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class Serializer:
    store = ... # type: Any
    encoding = ... # type: Any
    base = ... # type: Any
    def __init__(self, store): ...
    def serialize(self, stream, base=None, encoding=None, **args): ...
    def relativize(self, uri): ...
