# Stubs for ruamel.yaml.error (Python 2)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class YAMLError(Exception): ...

class MarkedYAMLError(YAMLError): ...
